@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-__version__ = '1.5'
+__version__ = '1.6'
 __author__  = 'Olivier DUFAILLY'
 __license__ = 'BSD'
 
@@ -84,6 +84,18 @@ def cmp_to_key(mycmp):
             return mycmp(self.obj, other.obj) != 0
     return K
 
+
+class UsageError(Exception):
+  ''' Exception used to manage 'usage' errors:
+  - Syntax Errors
+  - User Input Errors
+  - Missing actors, groups, ...
+  '''
+  def __init__(self, msg, *args):
+    super().__init__(msg)
+    
+
+
 class LogStatus:
   ''' Simple Logging class used to return statuses of complex algorithms '''
   def __init__(self, usedLogging = True):
@@ -96,7 +108,8 @@ class LogStatus:
     To be Overloaded for MMI purpose.
     Called by status(), worstStatus and logCond() methods
     '''
-    self.msg = self.__class__.__name__  + ':' + msg.format(*args)
+    sm = self.__class__.__name__  + ':' + msg.format(*args)
+    self.msg = self.msg+' '+sm if self.msg else sm
     if self.uselog:
       logging.info(self.msg)
     return self.msg
@@ -118,4 +131,9 @@ class LogStatus:
       self.info(msg, *args)
     return cond
   
+  def raiseCode(self, ret=C_OK, msg='', *args):
+    if ret!=C_OK:
+      self.status(ret=ret, msg=msg, *args)
+      raise UsageError(msg, self)
+    
   
