@@ -349,16 +349,9 @@ class ChannelDescriptor(LogStatus):
       self.chanType = self.gt.getPoserType()
       logging.info("Channel [%s:%s] exists for actor[%s] at %d", self.chanName, self.chanType.token, self.actorName, self.no)
 
-    # Check channel type : valueParm, visibility, geomChan
-#     if self.chanType not in (PoserToken.E_valueParm, PoserToken.E_geomChan, PoserToken.E_targetGeom, PoserToken.E_visibility):
-      # Incorrect channel type  ... But will work for 'upgrade' Not a failure anymore
-      # Keep existing channel data
-#       if self.gt:
-#         self.min = self.gt.getMin()
-#         self.max = self.gt.getMax()
-#         self.trackingScale = self.gt.getTrackingScale()
-#       logging.info("Other Channel Type [%s] for actor[%s] at column %d", self.chanType.token, self.actorName, self.no)
-
+    # Check channel type : valueParm, visibility, geomChan, ...
+    # if self.chanType not in (PoserToken.E_valueParm, PoserToken.E_geomChan, PoserToken.E_targetGeom, PoserToken.E_visibility):
+    #   Incorrect channel type  ... But will work for 'upgrade' Not a failure anymore
     try:
       if self.chanType==PoserToken.E_geomChan:
         self.initValue = 0
@@ -593,7 +586,7 @@ class ChannelImportAnalysis: # implements PoserConst
               strkey = strkey + '(' + self.tabChan[nolgn][nocol] + ',' + self.tabChan[nolgn + 1][nocol] + '),'
             nolgn += 2
 
-          lstOps.append('? {:s} ({:s})'.format(qualifiedName, strkey))
+          lstOps.append(f'? {qualifiedName} ({strkey})')
           nolgn-=1 # Push Back one line, because the optkeys may be followed by others operations
 
       nolgn+=1
