@@ -146,7 +146,6 @@ class Figure():
     super(Figure, self).__init__()
 
     self._pf = pf
-    #self._bodyIdx = idx
 
     #  figureResFile of the figure (single and shared with the PoserFile)
     self._bodyIdx = PoserConst.C_BAD_INDEX if idx==0 else idx
@@ -250,7 +249,7 @@ class Figure():
   # Return the name of the figure used by channel references
   #    
   def getRefName(self):
-    return "Figure " + str(self._bodyIdx)
+    return f"Figure {self._bodyIdx}"
 
   # 
   # @return the printName
@@ -398,6 +397,7 @@ class Figure():
     ''' Add a Magnet to a Figure.
     Create the deformer channels in the pointed actors and optionaly bind them to a master Value Param.
     The controling channel is created either with a valueOpDeltaAdd or a valueOpKey.
+    Create the masterChannel if needed
 
     Parameters
     ----------
@@ -426,8 +426,10 @@ class Figure():
     ret = C_OK
     
     smartParent = baseProp.getAttribut(PoserToken.E_smarParent).getValue()
-
-    actorDest = self.findActor(smartParent)
+    
+    # When the smartParent has no index, try to find it alone
+    idx = index(smartParent)
+    actorDest = self.findActor(smartParent, withIndex=(idx>0))
     if not actorDest:
       logging.warning("Figure[%s] has no Actor[%s] required by Magnet[%s]", self.getPrintName(), smartParent, baseProp.getName())
       return C_UNKNOWN
@@ -438,6 +440,10 @@ class Figure():
     sphereZone.deleteAttribut(PoserToken.E_smarParent.token)
 
     baseProp.setParent(actorDest.getName())
+    # Link (by index) the propo to their new figure
+    baseProp.setIndex(self.getBodyIndex())
+    deformerProp.setIndex(self.getBodyIndex())
+    sphereZone.setIndex(self.getBodyIndex())
     deformerProp.setParent(baseProp.getName())
     sphereZone.setParent(actorDest.getName())
 
@@ -445,13 +451,16 @@ class Figure():
     self._lstActor += ldesc
     self.createActorLinks(ldesc, weldActors=False)
 
+    # Ensure the master channel name exists
+    mgt = self.updateOrCreateValueParm(masterChannelName) if masterChannelName else None
+
     # Create Deformer Channels
     bodyName = self.getRoot() # PoserConst.C_BODY + ":" + str(self._bodyIdx)
     for targetName in [ po.getValue() for po in deformerProp.getLstAttr() if po.getPoserType()==PoserToken.E_deformTarget ]:
-      targetActor = self.findActor(targetName)
+      targetActor = self.findActor(targetName, withIndex=(index(targetName)>0))
 
       if targetActor: 
-        dparm = targetActor.CreateDeformerP(deformerProp.getName(), sphereZone.getName(), deformerProp.getName(), isHidden=True)
+        dparm = targetActor.CreateDeformerP(deformerProp.getName(), sphereZone.getName(), deformerProp.getName(), isHidden=(mgt is not None))
 
         if masterChannelName:
           if keys:
@@ -461,7 +470,7 @@ class Figure():
           
           dparm.addVOD(vop)
       else:
-        logging.warning("Figure[%s] has no Actor[%s] for Magnet[%s]", self.getPrintName(), targetName, deformerProp.getName())
+        logging.warning("Figure[%s] has no Target Actor[%s] for Magnet[%s]", self.getPrintName(), targetName, deformerProp.getName())
         ret = min(ret, C_FAIL)
 
     return ret
@@ -1088,23 +1097,19 @@ class Figure():
     '''
     retmask = 0
     lstActor = self.getDescendant()
-    for actor in lstActor:
-      if actor!=lstActor[0]:
-        lstDesc = self.getWelded(actor.getName())
-        #if lstDesc:
-        for descGn in lstDesc:
-          pa = self.findActor(descGn)
-          if pa.getGeomType()==PoserConst.GT_LOCAL_OBJFILE:
-            retmask |= PoserConst.C_HAS_LOCAL_OBJFILE
-          else:
-            if pa.getGeomType()==PoserConst.GT_INTERNAL:
-              retmask |= PoserConst.C_HAS_INTERNAL
-          if pa.getAltGeomList():
-            gtalt = pa.getAltGeomChannel()
-            valFrame0 = int(gtalt.getKeysFactor(0))
-
-            if valFrame0 != 0:
-              retmask |= PoserConst.C_HAS_ALT_GEOM
+    for pa in lstActor:
+      # FIX: Useless recursion since pypos3d > 1.0
+      if pa.getGeomType()==PoserConst.GT_LOCAL_OBJFILE:
+        retmask |= PoserConst.C_HAS_LOCAL_OBJFILE
+      elif pa.getGeomType()==PoserConst.GT_INTERNAL:
+        retmask |= PoserConst.C_HAS_INTERNAL
+        
+      if pa.getAltGeomList(): # Test the existance of AlternateGeom, not only the usage at frame 0
+        # gtalt = pa.getAltGeomChannel()
+        # valFrame0 = int(gtalt.getKeysFactor(0))
+        #
+        # if valFrame0 != 0:
+        retmask |= PoserConst.C_HAS_ALT_GEOM
 
     return retmask
 
@@ -1563,11 +1568,12 @@ class Figure():
           fp.status(C_FAIL, 'Material Map [{:s}] Syntax Error:{:s}', fp.geomGroup.getName(), fp.name)
           
       except (SyntaxError, NameError) as se:
-        estr = 'Syntax Error in Material Map' + str(type(se)) + ' ==> ' + str(se.args) + '(' + str(se) + ')'      
-        fp.status(C_FAIL, 'Material Map [{:s}] {:s}', fp.geomGroup.getName(), estr)
+        fp.status(C_FAIL, 'Material Map [{:s}] {:s}', fp.geomGroup.getName(), \
+                  f'Syntax Error in Material Map {type(se)} ==> {se.args}({se})')
     else:
       for mat in (lstMat if fp.name=='*' else [ fp.geomGroup.getMaterial(fp.name), ]):
         self.addMaterial(PoserMaterial(src=mat), replace=True)
+        logging.info('Material Copied %s', mat.getName())
 
 
   def __transformGeom(self, grp, fp:'FigurePart'):
@@ -1726,6 +1732,7 @@ class Figure():
         act.setCastsShadow(True) # FIX: To have shadows on each parts
         act.setVisible(True)
         act.setDisplayMode('USEPARENT')
+        act.setBend(True) # FIX: To allow part to be modified by magnets
         act.addAttribut(SimpleAttribut(PoserToken.E_backfaceCull, '0'))
         act.addAttribut(SimpleAttribut(PoserToken.E_visibleInReflections, '1'))
         act.addAttribut(SimpleAttribut(PoserToken.E_visibleInRender, '1'))
