@@ -7,7 +7,7 @@ import logging
 from langutil import RemoveExt, C_FAIL, C_OK, C_ERROR, C_FILE_NOT_FOUND, UsageError
 from pypos3d.wftk.WFBasic import C_BAD_DELTAINDEX, C_BAD_DELTACOUNT, C_NODELTA, Vector3d, Point3d
 from pypos3d.wftk.PoserFileParser import PoserFileParser, ParsingErrorException
-from pypos3d.pftk.PoserBasic import PoserConst, PoserToken, PToken, buildRelPath, getRealPath, index, TAS, WBoolLine, create, Lang
+from pypos3d.pftk.PoserBasic import PoserConst, PoserToken, PToken, buildRelPath, getRealPath, index, chgIndex, TAS, WBoolLine, create, Lang
 from pypos3d.pftk.GeomCustom import GeomCustom
 from pypos3d.pftk.StructuredAttribut import StructuredAttribut, AlternateGeom, Deltas, ValueOpDelta, ChannelMorphStatus, \
     GenericTransform, ChannelMorphStatusList, findNewDelta, filterLength, calcMapping_KDTree, CustomData, DeltaPoint
@@ -740,7 +740,7 @@ class PoserMeshedObject(StructuredAttribut):
 
         # Foreach morph target ==> Exploit tabMapping for srcGC
         for channelName in setTargetMorph:
-          altChannelName = channelName + "_Alt" + str(altno)
+          altChannelName = f'{channelName}_Alt{altno}'
           logging.info("Creating deltas for " + srcGC.getName() + "." + channelName + " into:" + altChannelName)
           setFoundDeltas = findNewDelta(tabMapping, refMeshedObj, channelName)
           
@@ -863,7 +863,7 @@ class PoserMeshedObject(StructuredAttribut):
     if geomChan:      
       destGT = self.updateOrCreateVP(targetMorphName, minVal=0.0, maxVal=1.0, applyLimits=False)
 
-      targetGT = self.updateOrCreate(targetMorphName + "_Alt" + str(altGeomNo), self.getName(), refGeomGrp, setNewDeltas, srcActor.getFigure().getBodyIndex(), False)
+      targetGT = self.updateOrCreate(f'{targetMorphName}_Alt{altGeomNo}', self.getName(), refGeomGrp, setNewDeltas, srcActor.getFigure().getBodyIndex(), False)
       
       vod = ValueOpDelta(PoserToken.E_valueOpKey, srcActor.getFigure().getRefName(), srcActor.getName(), geomChan.getName(), 0.0)
 
@@ -1343,6 +1343,14 @@ class PoserProp(PoserMeshedObject):
     ''' Return the figure index or 0 if the prop is outside any figure ''' 
     return self.idx
 
+  def setIndex(self, ni):
+    ''' Set a new figure index for the PoserProp.
+    Need to be overloaded by descendant to manage specific attributes.
+    Does not change parent's index (supposed to be set externaly)
+    Does not change actors referenced by channels (use changeReference for that)
+    '''
+    self.setName( chgIndex(self.getName(), ni) )
+
   def createChannelMorphList(self, stm):
     lstCS = ChannelMorphStatusList()
 
@@ -1366,6 +1374,14 @@ class BaseProp(PoserProp):
     else:
       super(BaseProp, self).write(fw, pfx)
 
+
+  def setIndex(self, ni):
+    ''' Set a new figure index for the BaseProp. '''
+    super(BaseProp, self).setIndex(ni)
+    
+    dp = self.getAttribut(PoserToken.E_deformerProp)
+    dp.setValue( chgIndex(dp.getValue(), ni))
+
 # 
 # Represents the Magnet object of a Magner deformer.
 # Just to avoid interactions with actors or props that have geoms
@@ -1374,6 +1390,16 @@ class MagnetDeformerProp(PoserProp):
   def __init__(self):
     super(MagnetDeformerProp, self).__init__()
 
+  def setIndex(self, ni):
+    ''' Set a new figure index for the BaseProp. '''
+    super(MagnetDeformerProp, self).setIndex(ni)
+    
+    for po in self._lstAttr:
+      if po.getPoserType() in (PoserToken.E_deformTarget, PoserToken.E_addZone ):
+        po.setValue( chgIndex(po.getValue(), ni))
+      if po.getPoserType() == PoserToken.E_baseProp: # Remember baseProp is Ambiguous
+        po.setName( chgIndex(po.getName(), ni))
+
 # Represents the Spehirc zone of a Magner deformer.
 # Just to avoid interactions with actors or props that have geoms
 class SphereZoneProp(PoserProp):
