@@ -30,6 +30,7 @@ C_MISSING_FACEMAT  = -110
 # TODO: for optim Add -FEPSILON
 FEPSILON = 1e-6
 FEPSILON2 = FEPSILON*FEPSILON
+FEPSILON3 = FEPSILON*FEPSILON*FEPSILON
 
 # -------------------------------------------
 # Face Attributs
@@ -40,11 +41,17 @@ FEPSILON2 = FEPSILON*FEPSILON
 C_FACE_NONE     = 0x00000000
 C_FACE_TEXT     = 0x01000000
 C_FACE_NORM     = 0x02000000
+C_FACE_SURF     = 0x04000000 # Used by Untriangularize algo to specify a surfacecomparison
 C_FACE_TEXTNORM = C_FACE_TEXT|C_FACE_NORM
 C_FACE_NOTEXT   = not C_FACE_TEXT
 C_FACE_NONROM   = not C_FACE_NORM
 C_FACE_MATMASK  = 0x00ffffff
 
+# Low weight bits for the untriangularize algorithm
+C_FACE_ORDER_LENGTH = 0x0000000
+C_FACE_ORDER_ANGLE  = 0x0000001
+C_FACE_ORDER_SURF   = 0x0000002
+
 #
 def getOBJFile(filename):
   ''' Return the file descriptor of a OBJ or OBZ geometry.
