@@ -239,9 +239,10 @@ class WaveGeom(object):
         except FileNotFoundError:
           logging.warning("Material file read Error:%s", self._libMaterialName)
           
-    else:
+    if not self.lstMat:
       # When the WaveGeom is not created from a file 
       # a default material is required
+      # FIX: Also required when the material list is empty at the end of the readInternal() call
       self.addMaterial("default") 
       
     #except Exception as e: # Should
@@ -1799,7 +1800,7 @@ class WaveGeom(object):
     return res
   
   
-  def unTriangularize(self, lstGrp=None, maxsin=FEPSILON):
+  def unTriangularize(self, lstGrp=None, maxsin=FEPSILON, algo=0, surfaceThreshold=0.1):
     ''' Untriangularize the current geometry (inplace).
     Triangular faces are merged when:
     * They have the same material
@@ -1817,6 +1818,20 @@ class WaveGeom(object):
       Maximal value for the sinus of the angle of both
       normal to permit a merge
       
+    algo: bitmask for algorithm selection, default = C_FACE_NONE
+      Add C_FACE_SURF for relative surface filtering. 
+      
+      Add either C_FACE_ORDER_LENGTH, C_FACE_ORDER_ANGLE or C_FACE_ORDER_SURF for surface choice ordering
+      The ordering is used to choose the merged triangle between the 3 neighbours of a destination triangle.
+      C_FACE_ORDER_LENGTH: The triangle with the greastest common edge is merged
+      C_FACE_ORDER_ANGLE: The triangle with the smallest angle is merged
+      C_FACE_ORDER_SURF: The triangle with the greatest relative surface is merged
+      
+    surfaceThreshold: float, default=0.1
+      Threshold used by the surface filtering to keep a triangle as a merging candidate.
+      The candidat is kept is its surface will represent more than 'surfaceThreshold' of the
+      merged quad surface.
+      
     Return
     ------
     int : 
@@ -1849,7 +1864,7 @@ class WaveGeom(object):
     
     for g in lgrp:
       nb = g.getNbFace()
-      r = g.unTriangularize(maxsin=maxsin)
+      r = g.unTriangularize(maxsin=maxsin, algo=algo, surfaceThreshold=surfaceThreshold)
       if r<C_OK:
         logging.info("Untriangularization of [%s] : %d faces not changed", g.getName(), nb)
       else:
@@ -1892,7 +1907,7 @@ def readGeom(fn, usemtl=False, imgdirpath=''):
     rin.close()
 
   except FileNotFoundError as e:
-    if WFBasic.PYPOS3D_TRACE: print ('File({0:s} - Read Error {1:s}'.format(fn, str(e.args)))
+    if WFBasic.PYPOS3D_TRACE: print(f'File({fn} - Read Error {e.args}')
 
   return gm
  
@@ -1994,7 +2009,7 @@ def PlaneCut(target, centerOrRepOrPlane, eu=None, ev=None, materialName='Section
     lastidx = target.getFaceLastIdx(faceno)
                         
     if lastidx-startidx<3:
-      if WFBasic.PYPOS3D_TRACE: print('  PlaneCut[{0:s}] ignoring face : {1:d}'.format(target.getName(), faceno))
+      if WFBasic.PYPOS3D_TRACE: print(f'  PlaneCut[{target.getName()}] ignoring face: {faceno}')
       continue
     
     # Retrieve the face attributs (Text,Norm, material) of the face to cut
@@ -2040,7 +2055,7 @@ def PlaneCut(target, centerOrRepOrPlane, eu=None, ev=None, materialName='Section
     lstEdgeVx = [ (vxtab[i], vxtab[i+1]) for i in range(0, len(vxtab)-1) ] + [ (vxtab[-1], vxtab[0]), ]
 
     if len(vxtab)<3:
-      if WFBasic.PYPOS3D_TRACE: print('  PlaneCut[{0:s}] ignoring cleaned face : {1:d}'.format(target.getName(), faceno))
+      if WFBasic.PYPOS3D_TRACE: print(f'  PlaneCut[{target.getName()}] ignoring cleaned face: {faceno}')
       
       # Determine if the face shall be kept
       v = FaceVisibility(lstEdgeVx, cuttingVect)
@@ -2060,11 +2075,11 @@ def PlaneCut(target, centerOrRepOrPlane, eu=None, ev=None, materialName='Section
         
       if multiple: # In such case, lstNewFaceVx is a list of list of Vertex
         if WFBasic.PYPOS3D_TRACE: 
-          print('  PlaneCut[{0:s}].Cutting[{1:d}]: {2:d} faces'.format(target.getName(), faceno, len(lstNewFaceVx)))
+          print(f'  PlaneCut[{target.getName()}].Cutting[{faceno}]: {len(lstNewFaceVx)} faces')
         nFaceList += lstNewFaceVx
         nMatList  += [ fattr ] * len(lstNewFaceVx)
       else:
-        if WFBasic.PYPOS3D_TRACE: print('  PlaneCut[{0:s}].Cutting[{1:d}]: {2:d} vertex'.format(target.getName(), faceno, len(lstNewFaceVx)))
+        if WFBasic.PYPOS3D_TRACE: print(f'  PlaneCut[{target.getName()}].Cutting[{faceno}]: {len(lstNewFaceVx)} vertex')
         nFaceList.append(lstNewFaceVx)
         nMatList.append(fattr)
         
@@ -2189,7 +2204,7 @@ def PlaneSplit(target, centerOrRepOrPlane, eu=None, ev=None, radialLimit=0.0, ma
     lastidx = target.getFaceLastIdx(faceno)
                         
     if lastidx-startidx<3:
-      if WFBasic.PYPOS3D_TRACE: print('  [{0:s}] ignoring face : {1:d}'.format(target.getName(), faceno))
+      if WFBasic.PYPOS3D_TRACE: print(f'  [{target.getName()}] ignoring face: {faceno}')
       continue
     
     # Retrieve the material and the attributs of the face to cut
@@ -2235,7 +2250,7 @@ def PlaneSplit(target, centerOrRepOrPlane, eu=None, ev=None, radialLimit=0.0, ma
     lstEdgeVx = [ (vxtab[i], vxtab[i+1]) for i in range(0, len(vxtab)-1) ] + [ (vxtab[-1], vxtab[0]), ]
 
     if len(vxtab)<3:
-      if WFBasic.PYPOS3D_TRACE: print('  [{0:s}] ignoring cleaned face : {1:d}'.format(target.getName(), faceno))
+      if WFBasic.PYPOS3D_TRACE: print(f'  [{target.getName()}] ignoring cleaned face : {faceno}')
       
       lstNewFaceVx = [ v[0] for v in lstEdgeVx ]
 
@@ -2384,7 +2399,7 @@ def PlaneSlice(target, centerOrRepOrPlane, eu=None, ev=None, cutFaceMatLst=None,
     hasTexture = (fattr & C_FACE_TEXT)!=0
     
     if lastidx-startidx<3:
-      if WFBasic.PYPOS3D_TRACE: print('PlaneSlice[{0:s}] ignoring NON face : {1:d}'.format(target.getName(), faceno))
+      if WFBasic.PYPOS3D_TRACE: print(f'PlaneSlice[{target.getName()}] ignoring NON face: {faceno}')
       continue
     
     # Compute the list of enhanced Vertex, without aligned ones
@@ -2419,7 +2434,7 @@ def PlaneSlice(target, centerOrRepOrPlane, eu=None, ev=None, cutFaceMatLst=None,
     vxtab.append(nextPt)
  
     if len(vxtab)<3:
-      if WFBasic.PYPOS3D_TRACE: print('  PlaneSlice[{0:s}] ignoring cleaned face : {1:d}'.format(target.getName(), faceno))
+      if WFBasic.PYPOS3D_TRACE: print(f'  PlaneSlice[{target.getName()}] ignoring cleaned face: {faceno}')
       continue
 
     
